This is an automated email from the ASF dual-hosted git repository.

normanbreau pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/cordova-plugin-file.git


The following commit(s) were added to refs/heads/master by this push:
     new 1601b60  fix(types): Mark FileWriter.write to support ArrayBuffer data 
(#547)
1601b60 is described below

commit 1601b607e48f781b0305742cbb1a8fe670676992
Author: Philip Peitsch <philip.peit...@gmail.com>
AuthorDate: Thu Dec 8 01:57:26 2022 +1100

    fix(types): Mark FileWriter.write to support ArrayBuffer data (#547)
    
    FileWriter.js clearly supports this type, and it allows memory conscious 
users to
    avoid unnecessary duplication of the memory as occurs when using a Blob.
---
 types/index.d.ts | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/types/index.d.ts b/types/index.d.ts
index 469d862..aeb3e30 100644
--- a/types/index.d.ts
+++ b/types/index.d.ts
@@ -294,9 +294,9 @@ interface FileWriter extends FileSaver {
     length: number;
     /**
      * Write the supplied data to the file at position.
      * @param {Blob|string} data The blob to write.
      */
-    write(data: Blob|string): void;
+    write(data: Blob|string|ArrayBuffer): void;
     /**
      * The file position at which the next write will occur.
      * @param offset If nonnegative, an absolute byte offset into the file.


---------------------------------------------------------------------
@@ -294,9 +294,9 @@ interface FileWriter extends FileSaver {
     /**
      * Write the supplied data to the file at position.
-     * @param {Blob|string} data The blob to write.
+     * @param {Blob|string|ArrayBuffer} data The blob to write.
      */
To unsubscribe, e-mail: commits-unsubscr...@cordova.apache.org
For additional commands, e-mail: commits-h...@cordova.apache.org

Reply via email to